# towercrane

```python

towercrane config 

towercrane scan 
towercrane state

towercrane init 
towercrane upload 
towercrane remove 
towercrane download
  
 ```


## State lifecycle of a project 

local
cloud
local_and_cloud

upload
uploaded

remove
removed

download


